<?php

/**
 * @property CI_Controller $CI
 */
class Openai
{

    public function __construct()
    {
        $this->CI = &get_instance();
    }

    private function getHeader()
    {

        $AiTokenUrl = 'https://resources.vega6.info/open-ai-token';
        $res = $this->CI->adi->curl_get_authorization($AiTokenUrl, MEDIA_API_TOKEN);
        if ($res->status) {

            if (is_array($res->data) && count($res->data) >= 1) {
                $token = $res->data[0]->token;
                return array(
                    'Content-Type: application/json',
                    'Authorization: Bearer ' . $token,
                );
            }

        }

    }

    private function content_moderation($text)
    {
        $url = 'https://api.openai.com/v1/moderations';
        $headers = $this->getHeader();
        //$object = '{"input": "' . json_encode($text) . '"}';
        $object = array('input' => $text);
        $response = $this->CI->adi->curl_post_request($url, json_encode($object), 'yes', $headers);
        if (is_array($response)) {
            foreach ($response as $key => $value) {
                if ($value->flagged == true) {
                    return true;
                } else {
                    continue;
                }
            }
        }
    }

    public function generateContentGPT($message, $userId, $contentType)
    {
        $data = array(
            'status' => false,
            'message' => 'Some Error occurred',
        );
        $url = 'https://api.openai.com/v1/chat/completions';
        $headers = $this->getHeader();
        //print_r($message);
        $object = array(
            'model' => 'gpt-3.5-turbo',
            'messages' => $message,
            'temperature' => 0.7,
            'user' => 'user_' . $userId,
        );

        $response = $this->CI->adi->curl_post_request($url, json_encode($object), 'yes', $headers);
        if (isset($response->error)) {
            $data = array(
                'status' => false,
                'message' => $response->error,
            );
        }
        if (!empty($response) && !empty($response->id)) {
            $textGet = $response->choices[0]->message->content;
            $textGetArray = preg_split("/\r\n|\n|\r/", $textGet);
            $newText = array();
            if ($contentType == 'list') {
                if (!empty($textGetArray)) {
                    $r = 1;
                    foreach ($textGetArray as $str) {
                        if (!empty($str) && $str != ':') {
                            $str = str_replace($r . '.', '', $str);
                            $newText[] = $str;
                        }
                        $r++;
                    }
                }
            } else {
                $newText[] = $textGet;
            }
            $check = $this->content_moderation($newText);
            $insert['userId'] = $userId;
            $insert['message'] = json_encode($message);
            $insert['response'] = json_encode($newText);

            $this->CI->DatabaseModel->insertData('ai_review', $insert);
            if ($check) {
                $data = array(
                    'status' => false,
                    'message' => 'Input provided is against our content policy. Please try again',
                );
            } else {

                $data = array(
                    'status' => true,
                    'message' => 'Success',
                    'data' => $newText,
                    'original' => $textGet,
                );
            }
        }

        return $data;
    }

    public function generateContent($text, $userId, $contentType)
    {
        $data = array(
            'status' => false,
            'message' => 'Some Error occurred',
        );
        $url = 'https://api.openai.com/v1/completions';
        $headers = $this->getHeader();
        $object = array(
            'model' => 'text-davinci-002',
            'prompt' => $text,
            'temperature' => 0.7,
            'max_tokens' => 1080,
            'user' => 'user_' . $userId,
        );
        $response = $this->CI->adi->curl_post_request($url, json_encode($object), 'yes', $headers);
        if (isset($response->error)) {
            $data = array(
                'status' => false,
                'message' => $response->error,
            );
        }
        if (!empty($response) && !empty($response->id)) {
            $textGet = $response->choices[0]->text;
            $textGetArray = preg_split("/\r\n|\n|\r/", $textGet);
            $newText = array();
            if ($contentType == 'list') {
                if (!empty($textGetArray)) {
                    $r = 1;
                    foreach ($textGetArray as $str) {
                        if (!empty($str) && $str != ':') {
                            $str = str_replace($r . '.', '', $str);
                            $newText[] = $str;

                        }
                        $r++;
                    }
                }
            } else {
                $newText[] = $textGet;
            }

            $check = $this->content_moderation($newText);
            if ($check) {
                $data = array(
                    'status' => false,
                    'message' => 'Input provided is against our content policy. Please try again',
                );
            } else {

                $data = array(
                    'status' => true,
                    'message' => 'Success',
                    'data' => $newText,
                );
            }
        }

        return $data;
    }

    public function keyword($text, $userId)
    {

        $data = array(
            'status' => false,
            'message' => 'Some Error occurred',
        );
        $url = 'https://api.openai.com/v1/completions';
        $textFinal = 'Extract keywords from the following text: ' . $text;
        $headers = $this->getHeader();
        $object = array(
            "model" => "text-davinci-002",
            "prompt" => $textFinal,
            "temperature" => 0.7,
            "max_tokens" => 256,
            "top_p" => 1,
            "user" => 'user_' . $userId,
        );
        $response = $this->CI->adi->curl_post_request($url, json_encode($object), 'yes', $headers);
        if (isset($response->error)) {
            $data = array(
                'status' => false,
                'message' => 'Something went wrong.',
            );
        }
        if (!empty($response) && $response->id) {
            $textGet = $response->choices[0]->text;
            $check = $this->content_moderation($textGet);
            if ($check) {
                $data = array(
                    'status' => false,
                    'message' => 'Input provided is against our content policy. Please try again',
                );
            } else {

                $data = array(
                    'status' => true,
                    'message' => 'Success',
                    'keywords' => explode(',', $textGet),
                );
            }
        }

        return $data;
    }

}
